# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetJobResult',
    'AwaitableGetJobResult',
    'get_job',
    'get_job_output',
]

@pulumi.output_type
class GetJobResult:
    """
    A collection of values returned by getJob.
    """
    def __init__(__self__, advanced_settings_json=None, auto_deploy=None, auto_preview=None, built_in_environment_variables=None, cpu=None, deployment_restrictions=None, deployment_stage_id=None, environment_id=None, environment_variable_aliases=None, environment_variable_overrides=None, environment_variables=None, external_host=None, healthchecks=None, id=None, internal_host=None, max_duration_seconds=None, max_nb_restart=None, memory=None, name=None, port=None, schedule=None, secret_aliases=None, secret_overrides=None, secrets=None, source=None):
        if advanced_settings_json and not isinstance(advanced_settings_json, str):
            raise TypeError("Expected argument 'advanced_settings_json' to be a str")
        pulumi.set(__self__, "advanced_settings_json", advanced_settings_json)
        if auto_deploy and not isinstance(auto_deploy, bool):
            raise TypeError("Expected argument 'auto_deploy' to be a bool")
        pulumi.set(__self__, "auto_deploy", auto_deploy)
        if auto_preview and not isinstance(auto_preview, bool):
            raise TypeError("Expected argument 'auto_preview' to be a bool")
        pulumi.set(__self__, "auto_preview", auto_preview)
        if built_in_environment_variables and not isinstance(built_in_environment_variables, list):
            raise TypeError("Expected argument 'built_in_environment_variables' to be a list")
        pulumi.set(__self__, "built_in_environment_variables", built_in_environment_variables)
        if cpu and not isinstance(cpu, int):
            raise TypeError("Expected argument 'cpu' to be a int")
        pulumi.set(__self__, "cpu", cpu)
        if deployment_restrictions and not isinstance(deployment_restrictions, list):
            raise TypeError("Expected argument 'deployment_restrictions' to be a list")
        pulumi.set(__self__, "deployment_restrictions", deployment_restrictions)
        if deployment_stage_id and not isinstance(deployment_stage_id, str):
            raise TypeError("Expected argument 'deployment_stage_id' to be a str")
        pulumi.set(__self__, "deployment_stage_id", deployment_stage_id)
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if environment_variable_aliases and not isinstance(environment_variable_aliases, list):
            raise TypeError("Expected argument 'environment_variable_aliases' to be a list")
        pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides and not isinstance(environment_variable_overrides, list):
            raise TypeError("Expected argument 'environment_variable_overrides' to be a list")
        pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables and not isinstance(environment_variables, list):
            raise TypeError("Expected argument 'environment_variables' to be a list")
        pulumi.set(__self__, "environment_variables", environment_variables)
        if external_host and not isinstance(external_host, str):
            raise TypeError("Expected argument 'external_host' to be a str")
        pulumi.set(__self__, "external_host", external_host)
        if healthchecks and not isinstance(healthchecks, dict):
            raise TypeError("Expected argument 'healthchecks' to be a dict")
        pulumi.set(__self__, "healthchecks", healthchecks)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if internal_host and not isinstance(internal_host, str):
            raise TypeError("Expected argument 'internal_host' to be a str")
        pulumi.set(__self__, "internal_host", internal_host)
        if max_duration_seconds and not isinstance(max_duration_seconds, int):
            raise TypeError("Expected argument 'max_duration_seconds' to be a int")
        pulumi.set(__self__, "max_duration_seconds", max_duration_seconds)
        if max_nb_restart and not isinstance(max_nb_restart, int):
            raise TypeError("Expected argument 'max_nb_restart' to be a int")
        pulumi.set(__self__, "max_nb_restart", max_nb_restart)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if schedule and not isinstance(schedule, dict):
            raise TypeError("Expected argument 'schedule' to be a dict")
        pulumi.set(__self__, "schedule", schedule)
        if secret_aliases and not isinstance(secret_aliases, list):
            raise TypeError("Expected argument 'secret_aliases' to be a list")
        pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides and not isinstance(secret_overrides, list):
            raise TypeError("Expected argument 'secret_overrides' to be a list")
        pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)
        if source and not isinstance(source, dict):
            raise TypeError("Expected argument 'source' to be a dict")
        pulumi.set(__self__, "source", source)

    @property
    @pulumi.getter(name="advancedSettingsJson")
    def advanced_settings_json(self) -> str:
        return pulumi.get(self, "advanced_settings_json")

    @property
    @pulumi.getter(name="autoDeploy")
    def auto_deploy(self) -> bool:
        return pulumi.get(self, "auto_deploy")

    @property
    @pulumi.getter(name="autoPreview")
    def auto_preview(self) -> bool:
        return pulumi.get(self, "auto_preview")

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> Sequence['outputs.GetJobBuiltInEnvironmentVariableResult']:
        return pulumi.get(self, "built_in_environment_variables")

    @property
    @pulumi.getter
    def cpu(self) -> Optional[int]:
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter(name="deploymentRestrictions")
    def deployment_restrictions(self) -> Optional[Sequence['outputs.GetJobDeploymentRestrictionResult']]:
        return pulumi.get(self, "deployment_restrictions")

    @property
    @pulumi.getter(name="deploymentStageId")
    def deployment_stage_id(self) -> str:
        return pulumi.get(self, "deployment_stage_id")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> str:
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Sequence['outputs.GetJobEnvironmentVariableAliasResult']:
        return pulumi.get(self, "environment_variable_aliases")

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Optional[Sequence['outputs.GetJobEnvironmentVariableOverrideResult']]:
        return pulumi.get(self, "environment_variable_overrides")

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[Sequence['outputs.GetJobEnvironmentVariableResult']]:
        return pulumi.get(self, "environment_variables")

    @property
    @pulumi.getter(name="externalHost")
    def external_host(self) -> str:
        return pulumi.get(self, "external_host")

    @property
    @pulumi.getter
    def healthchecks(self) -> Optional['outputs.GetJobHealthchecksResult']:
        return pulumi.get(self, "healthchecks")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internalHost")
    def internal_host(self) -> str:
        return pulumi.get(self, "internal_host")

    @property
    @pulumi.getter(name="maxDurationSeconds")
    def max_duration_seconds(self) -> int:
        return pulumi.get(self, "max_duration_seconds")

    @property
    @pulumi.getter(name="maxNbRestart")
    def max_nb_restart(self) -> int:
        return pulumi.get(self, "max_nb_restart")

    @property
    @pulumi.getter
    def memory(self) -> Optional[int]:
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def port(self) -> int:
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def schedule(self) -> 'outputs.GetJobScheduleResult':
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Optional[Sequence['outputs.GetJobSecretAliasResult']]:
        return pulumi.get(self, "secret_aliases")

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[Sequence['outputs.GetJobSecretOverrideResult']]:
        return pulumi.get(self, "secret_overrides")

    @property
    @pulumi.getter
    def secrets(self) -> Optional[Sequence['outputs.GetJobSecretResult']]:
        return pulumi.get(self, "secrets")

    @property
    @pulumi.getter
    def source(self) -> 'outputs.GetJobSourceResult':
        return pulumi.get(self, "source")


class AwaitableGetJobResult(GetJobResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetJobResult(
            advanced_settings_json=self.advanced_settings_json,
            auto_deploy=self.auto_deploy,
            auto_preview=self.auto_preview,
            built_in_environment_variables=self.built_in_environment_variables,
            cpu=self.cpu,
            deployment_restrictions=self.deployment_restrictions,
            deployment_stage_id=self.deployment_stage_id,
            environment_id=self.environment_id,
            environment_variable_aliases=self.environment_variable_aliases,
            environment_variable_overrides=self.environment_variable_overrides,
            environment_variables=self.environment_variables,
            external_host=self.external_host,
            healthchecks=self.healthchecks,
            id=self.id,
            internal_host=self.internal_host,
            max_duration_seconds=self.max_duration_seconds,
            max_nb_restart=self.max_nb_restart,
            memory=self.memory,
            name=self.name,
            port=self.port,
            schedule=self.schedule,
            secret_aliases=self.secret_aliases,
            secret_overrides=self.secret_overrides,
            secrets=self.secrets,
            source=self.source)


def get_job(advanced_settings_json: Optional[str] = None,
            auto_deploy: Optional[bool] = None,
            auto_preview: Optional[bool] = None,
            cpu: Optional[int] = None,
            deployment_restrictions: Optional[Sequence[pulumi.InputType['GetJobDeploymentRestrictionArgs']]] = None,
            deployment_stage_id: Optional[str] = None,
            environment_variable_aliases: Optional[Sequence[pulumi.InputType['GetJobEnvironmentVariableAliasArgs']]] = None,
            environment_variable_overrides: Optional[Sequence[pulumi.InputType['GetJobEnvironmentVariableOverrideArgs']]] = None,
            environment_variables: Optional[Sequence[pulumi.InputType['GetJobEnvironmentVariableArgs']]] = None,
            healthchecks: Optional[pulumi.InputType['GetJobHealthchecksArgs']] = None,
            id: Optional[str] = None,
            max_duration_seconds: Optional[int] = None,
            max_nb_restart: Optional[int] = None,
            memory: Optional[int] = None,
            port: Optional[int] = None,
            secret_aliases: Optional[Sequence[pulumi.InputType['GetJobSecretAliasArgs']]] = None,
            secret_overrides: Optional[Sequence[pulumi.InputType['GetJobSecretOverrideArgs']]] = None,
            secrets: Optional[Sequence[pulumi.InputType['GetJobSecretArgs']]] = None,
            source: Optional[pulumi.InputType['GetJobSourceArgs']] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetJobResult:
    """
    ## # Job (Data Source)

    Provides a Qovery job resource. This can be used to create and manage Qovery job registry.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_job = qovery.get_job(id="<job_id>")
    ```
    """
    __args__ = dict()
    __args__['advancedSettingsJson'] = advanced_settings_json
    __args__['autoDeploy'] = auto_deploy
    __args__['autoPreview'] = auto_preview
    __args__['cpu'] = cpu
    __args__['deploymentRestrictions'] = deployment_restrictions
    __args__['deploymentStageId'] = deployment_stage_id
    __args__['environmentVariableAliases'] = environment_variable_aliases
    __args__['environmentVariableOverrides'] = environment_variable_overrides
    __args__['environmentVariables'] = environment_variables
    __args__['healthchecks'] = healthchecks
    __args__['id'] = id
    __args__['maxDurationSeconds'] = max_duration_seconds
    __args__['maxNbRestart'] = max_nb_restart
    __args__['memory'] = memory
    __args__['port'] = port
    __args__['secretAliases'] = secret_aliases
    __args__['secretOverrides'] = secret_overrides
    __args__['secrets'] = secrets
    __args__['source'] = source
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getJob:getJob', __args__, opts=opts, typ=GetJobResult).value

    return AwaitableGetJobResult(
        advanced_settings_json=pulumi.get(__ret__, 'advanced_settings_json'),
        auto_deploy=pulumi.get(__ret__, 'auto_deploy'),
        auto_preview=pulumi.get(__ret__, 'auto_preview'),
        built_in_environment_variables=pulumi.get(__ret__, 'built_in_environment_variables'),
        cpu=pulumi.get(__ret__, 'cpu'),
        deployment_restrictions=pulumi.get(__ret__, 'deployment_restrictions'),
        deployment_stage_id=pulumi.get(__ret__, 'deployment_stage_id'),
        environment_id=pulumi.get(__ret__, 'environment_id'),
        environment_variable_aliases=pulumi.get(__ret__, 'environment_variable_aliases'),
        environment_variable_overrides=pulumi.get(__ret__, 'environment_variable_overrides'),
        environment_variables=pulumi.get(__ret__, 'environment_variables'),
        external_host=pulumi.get(__ret__, 'external_host'),
        healthchecks=pulumi.get(__ret__, 'healthchecks'),
        id=pulumi.get(__ret__, 'id'),
        internal_host=pulumi.get(__ret__, 'internal_host'),
        max_duration_seconds=pulumi.get(__ret__, 'max_duration_seconds'),
        max_nb_restart=pulumi.get(__ret__, 'max_nb_restart'),
        memory=pulumi.get(__ret__, 'memory'),
        name=pulumi.get(__ret__, 'name'),
        port=pulumi.get(__ret__, 'port'),
        schedule=pulumi.get(__ret__, 'schedule'),
        secret_aliases=pulumi.get(__ret__, 'secret_aliases'),
        secret_overrides=pulumi.get(__ret__, 'secret_overrides'),
        secrets=pulumi.get(__ret__, 'secrets'),
        source=pulumi.get(__ret__, 'source'))


@_utilities.lift_output_func(get_job)
def get_job_output(advanced_settings_json: Optional[pulumi.Input[Optional[str]]] = None,
                   auto_deploy: Optional[pulumi.Input[Optional[bool]]] = None,
                   auto_preview: Optional[pulumi.Input[Optional[bool]]] = None,
                   cpu: Optional[pulumi.Input[Optional[int]]] = None,
                   deployment_restrictions: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetJobDeploymentRestrictionArgs']]]]] = None,
                   deployment_stage_id: Optional[pulumi.Input[Optional[str]]] = None,
                   environment_variable_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetJobEnvironmentVariableAliasArgs']]]]] = None,
                   environment_variable_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetJobEnvironmentVariableOverrideArgs']]]]] = None,
                   environment_variables: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetJobEnvironmentVariableArgs']]]]] = None,
                   healthchecks: Optional[pulumi.Input[Optional[pulumi.InputType['GetJobHealthchecksArgs']]]] = None,
                   id: Optional[pulumi.Input[str]] = None,
                   max_duration_seconds: Optional[pulumi.Input[Optional[int]]] = None,
                   max_nb_restart: Optional[pulumi.Input[Optional[int]]] = None,
                   memory: Optional[pulumi.Input[Optional[int]]] = None,
                   port: Optional[pulumi.Input[Optional[int]]] = None,
                   secret_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetJobSecretAliasArgs']]]]] = None,
                   secret_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetJobSecretOverrideArgs']]]]] = None,
                   secrets: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetJobSecretArgs']]]]] = None,
                   source: Optional[pulumi.Input[Optional[pulumi.InputType['GetJobSourceArgs']]]] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetJobResult]:
    """
    ## # Job (Data Source)

    Provides a Qovery job resource. This can be used to create and manage Qovery job registry.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_job = qovery.get_job(id="<job_id>")
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['AwsCredentialsArgs', 'AwsCredentials']

@pulumi.input_type
class AwsCredentialsArgs:
    def __init__(__self__, *,
                 access_key_id: pulumi.Input[str],
                 organization_id: pulumi.Input[str],
                 secret_access_key: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AwsCredentials resource.
        :param pulumi.Input[str] access_key_id: Your AWS access key id.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] secret_access_key: Your AWS secret access key.
        :param pulumi.Input[str] name: Name of the aws credentials.
        """
        pulumi.set(__self__, "access_key_id", access_key_id)
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "secret_access_key", secret_access_key)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> pulumi.Input[str]:
        """
        Your AWS access key id.
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "access_key_id", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Input[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> pulumi.Input[str]:
        """
        Your AWS secret access key.
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "secret_access_key", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the aws credentials.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _AwsCredentialsState:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 secret_access_key: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AwsCredentials resources.
        :param pulumi.Input[str] access_key_id: Your AWS access key id.
        :param pulumi.Input[str] name: Name of the aws credentials.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] secret_access_key: Your AWS secret access key.
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if secret_access_key is not None:
            pulumi.set(__self__, "secret_access_key", secret_access_key)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        Your AWS access key id.
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_key_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the aws credentials.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> Optional[pulumi.Input[str]]:
        """
        Your AWS secret access key.
        """
        return pulumi.get(self, "secret_access_key")

    @secret_access_key.setter
    def secret_access_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_access_key", value)


class AwsCredentials(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 secret_access_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## # AwsCredentials (Resource)

        Provides a Qovery AWS credentials resource. This can be used to create and manage Qovery AWS credentials.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_aws_creds = qovery.AwsCredentials("myAwsCreds",
            organization_id=qovery_organization["my_organization"]["id"],
            access_key_id="<your-aws-access-key-id>",
            secret_access_key="<your-aws-secret-access-key>",
            opts=pulumi.ResourceOptions(depends_on=[qovery_organization["my_organization"]]))
        ```

        ## Import

        ```sh
         $ pulumi import qovery:index/awsCredentials:AwsCredentials my_aws_creds "<organization_id>,<aws_credentials_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_key_id: Your AWS access key id.
        :param pulumi.Input[str] name: Name of the aws credentials.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] secret_access_key: Your AWS secret access key.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AwsCredentialsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # AwsCredentials (Resource)

        Provides a Qovery AWS credentials resource. This can be used to create and manage Qovery AWS credentials.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_aws_creds = qovery.AwsCredentials("myAwsCreds",
            organization_id=qovery_organization["my_organization"]["id"],
            access_key_id="<your-aws-access-key-id>",
            secret_access_key="<your-aws-secret-access-key>",
            opts=pulumi.ResourceOptions(depends_on=[qovery_organization["my_organization"]]))
        ```

        ## Import

        ```sh
         $ pulumi import qovery:index/awsCredentials:AwsCredentials my_aws_creds "<organization_id>,<aws_credentials_id>"
        ```

        :param str resource_name: The name of the resource.
        :param AwsCredentialsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AwsCredentialsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 secret_access_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AwsCredentialsArgs.__new__(AwsCredentialsArgs)

            if access_key_id is None and not opts.urn:
                raise TypeError("Missing required property 'access_key_id'")
            __props__.__dict__["access_key_id"] = None if access_key_id is None else pulumi.Output.secret(access_key_id)
            __props__.__dict__["name"] = name
            if organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'organization_id'")
            __props__.__dict__["organization_id"] = organization_id
            if secret_access_key is None and not opts.urn:
                raise TypeError("Missing required property 'secret_access_key'")
            __props__.__dict__["secret_access_key"] = None if secret_access_key is None else pulumi.Output.secret(secret_access_key)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["accessKeyId", "secretAccessKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(AwsCredentials, __self__).__init__(
            'qovery:index/awsCredentials:AwsCredentials',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            secret_access_key: Optional[pulumi.Input[str]] = None) -> 'AwsCredentials':
        """
        Get an existing AwsCredentials resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_key_id: Your AWS access key id.
        :param pulumi.Input[str] name: Name of the aws credentials.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] secret_access_key: Your AWS secret access key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AwsCredentialsState.__new__(_AwsCredentialsState)

        __props__.__dict__["access_key_id"] = access_key_id
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["secret_access_key"] = secret_access_key
        return AwsCredentials(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> pulumi.Output[str]:
        """
        Your AWS access key id.
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the aws credentials.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> pulumi.Output[str]:
        """
        Your AWS secret access key.
        """
        return pulumi.get(self, "secret_access_key")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***


import asyncio
import importlib.metadata
import importlib.util
import inspect
import json
import os
import sys
import typing

import pulumi
import pulumi.runtime
from pulumi.runtime.sync_await import _sync_await

from semver import VersionInfo as SemverVersion
from parver import Version as PEP440Version


def get_env(*args):
    for v in args:
        value = os.getenv(v)
        if value is not None:
            return value
    return None


def get_env_bool(*args):
    str = get_env(*args)
    if str is not None:
        # NOTE: these values are taken from https://golang.org/src/strconv/atob.go?s=351:391#L1, which is what
        # Terraform uses internally when parsing boolean values.
        if str in ["1", "t", "T", "true", "TRUE", "True"]:
            return True
        if str in ["0", "f", "F", "false", "FALSE", "False"]:
            return False
    return None


def get_env_int(*args):
    str = get_env(*args)
    if str is not None:
        try:
            return int(str)
        except:
            return None
    return None


def get_env_float(*args):
    str = get_env(*args)
    if str is not None:
        try:
            return float(str)
        except:
            return None
    return None


def _get_semver_version():
    # __name__ is set to the fully-qualified name of the current module, In our case, it will be
    # <some module>._utilities. <some module> is the module we want to query the version for.
    root_package, *rest = __name__.split('.')

    # pkg_resources uses setuptools to inspect the set of installed packages. We use it here to ask
    # for the currently installed version of the root package (i.e. us) and get its version.

    # Unfortunately, PEP440 and semver differ slightly in incompatible ways. The Pulumi engine expects
    # to receive a valid semver string when receiving requests from the language host, so it's our
    # responsibility as the library to convert our own PEP440 version into a valid semver string.

    pep440_version_string = importlib.metadata.version(root_package)
    pep440_version = PEP440Version.parse(pep440_version_string)
    (major, minor, patch) = pep440_version.release
    prerelease = None
    if pep440_version.pre_tag == 'a':
        prerelease = f"alpha.{pep440_version.pre}"
    elif pep440_version.pre_tag == 'b':
        prerelease = f"beta.{pep440_version.pre}"
    elif pep440_version.pre_tag == 'rc':
        prerelease = f"rc.{pep440_version.pre}"
    elif pep440_version.dev is not None:
        prerelease = f"dev.{pep440_version.dev}"

    # The only significant difference between PEP440 and semver as it pertains to us is that PEP440 has explicit support
    # for dev builds, while semver encodes them as "prerelease" versions. In order to bridge between the two, we convert
    # our dev build version into a prerelease tag. This matches what all of our other packages do when constructing
    # their own semver string.
    return SemverVersion(major=major, minor=minor, patch=patch, prerelease=prerelease)


# Determine the version once and cache the value, which measurably improves program performance.
_version = _get_semver_version()
_version_str = str(_version)


def get_version():
    return _version_str

def get_resource_opts_defaults() -> pulumi.ResourceOptions:
    return pulumi.ResourceOptions(
        version=get_version(),
        plugin_download_url=get_plugin_download_url(),
    )

def get_invoke_opts_defaults() -> pulumi.InvokeOptions:
    return pulumi.InvokeOptions(
        version=get_version(),
        plugin_download_url=get_plugin_download_url(),
    )

def get_resource_args_opts(resource_args_type, resource_options_type, *args, **kwargs):
    """
    Return the resource args and options given the *args and **kwargs of a resource's
    __init__ method.
    """

    resource_args, opts = None, None

    # If the first item is the resource args type, save it and remove it from the args list.
    if args and isinstance(args[0], resource_args_type):
        resource_args, args = args[0], args[1:]

    # Now look at the first item in the args list again.
    # If the first item is the resource options class, save it.
    if args and isinstance(args[0], resource_options_type):
        opts = args[0]

    # If resource_args is None, see if "args" is in kwargs, and, if so, if it's typed as the
    # the resource args type.
    if resource_args is None:
        a = kwargs.get("args")
        if isinstance(a, resource_args_type):
            resource_args = a

    # If opts is None, look it up in kwargs.
    if opts is None:
        opts = kwargs.get("opts")

    return resource_args, opts


# Temporary: just use pulumi._utils.lazy_import once everyone upgrades.
def lazy_import(fullname):

    import pulumi._utils as u
    f = getattr(u, 'lazy_import', None)
    if f is None:
        f = _lazy_import_temp

    return f(fullname)


# Copied from pulumi._utils.lazy_import, see comments there.
def _lazy_import_temp(fullname):
    m = sys.modules.get(fullname, None)
    if m is not None:
        return m

    spec = importlib.util.find_spec(fullname)

    m = sys.modules.get(fullname, None)
    if m is not None:
        return m

    loader = importlib.util.LazyLoader(spec.loader)
    spec.loader = loader
    module = importlib.util.module_from_spec(spec)

    m = sys.modules.get(fullname, None)
    if m is not None:
        return m

    sys.modules[fullname] = module
    loader.exec_module(module)
    return module


class Package(pulumi.runtime.ResourcePackage):
    def __init__(self, pkg_info):
        super().__init__()
        self.pkg_info = pkg_info

    def version(self):
        return _version

    def construct_provider(self, name: str, typ: str, urn: str) -> pulumi.ProviderResource:
        if typ != self.pkg_info['token']:
            raise Exception(f"unknown provider type {typ}")
        Provider = getattr(lazy_import(self.pkg_info['fqn']), self.pkg_info['class'])
        return Provider(name, pulumi.ResourceOptions(urn=urn))


class Module(pulumi.runtime.ResourceModule):
    def __init__(self, mod_info):
        super().__init__()
        self.mod_info = mod_info

    def version(self):
        return _version

    def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
        class_name = self.mod_info['classes'].get(typ, None)

        if class_name is None:
            raise Exception(f"unknown resource type {typ}")

        TheClass = getattr(lazy_import(self.mod_info['fqn']), class_name)
        return TheClass(name, pulumi.ResourceOptions(urn=urn))


def register(resource_modules, resource_packages):
    resource_modules = json.loads(resource_modules)
    resource_packages = json.loads(resource_packages)

    for pkg_info in resource_packages:
        pulumi.runtime.register_resource_package(pkg_info['pkg'], Package(pkg_info))

    for mod_info in resource_modules:
        pulumi.runtime.register_resource_module(
            mod_info['pkg'],
            mod_info['mod'],
            Module(mod_info))


_F = typing.TypeVar('_F', bound=typing.Callable[..., typing.Any])


def lift_output_func(func: typing.Any) -> typing.Callable[[_F], _F]:
    """Decorator internally used on {fn}_output lifted function versions
    to implement them automatically from the un-lifted function."""

    func_sig = inspect.signature(func)

    def lifted_func(*args, opts=None, **kwargs):
        bound_args = func_sig.bind(*args, **kwargs)
        # Convert tuple to list, see pulumi/pulumi#8172
        args_list = list(bound_args.args)
        return pulumi.Output.from_input({
            'args': args_list,
            'kwargs': bound_args.kwargs
        }).apply(lambda resolved_args: func(*resolved_args['args'],
                                            opts=opts,
                                            **resolved_args['kwargs']))

    return (lambda _: lifted_func)


def call_plain(
    tok: str,
    props: pulumi.Inputs,
    res: typing.Optional[pulumi.Resource] = None,
    typ: typing.Optional[type] = None,
) -> typing.Any:
    """
    Wraps pulumi.runtime.plain to force the output and return it plainly.
    """

    output = pulumi.runtime.call(tok, props, res, typ)

    # Ingoring deps silently. They are typically non-empty, r.f() calls include r as a dependency.
    result, known, secret, _ = _sync_await(asyncio.ensure_future(_await_output(output)))

    problem = None
    if not known:
        problem = ' an unknown value'
    elif secret:
        problem = ' a secret value'

    if problem:
        raise AssertionError(
            f"Plain resource method '{tok}' incorrectly returned {problem}. "
            + "This is an error in the provider, please report this to the provider developer."
        )

    return result


async def _await_output(o: pulumi.Output[typing.Any]) -> typing.Tuple[object, bool, bool, set]:
    return (
        await o._future,
        await o._is_known,
        await o._is_secret,
        await o._resources,
    )

def get_plugin_download_url():
	return "github://api.github.com/dirien/pulumi-qovery"



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetClusterResult',
    'AwaitableGetClusterResult',
    'get_cluster',
    'get_cluster_output',
]

@pulumi.output_type
class GetClusterResult:
    """
    A collection of values returned by getCluster.
    """
    def __init__(__self__, advanced_settings_json=None, cloud_provider=None, credentials_id=None, description=None, disk_size=None, features=None, id=None, instance_type=None, kubernetes_mode=None, max_running_nodes=None, min_running_nodes=None, name=None, organization_id=None, region=None, routing_tables=None, state=None):
        if advanced_settings_json and not isinstance(advanced_settings_json, str):
            raise TypeError("Expected argument 'advanced_settings_json' to be a str")
        pulumi.set(__self__, "advanced_settings_json", advanced_settings_json)
        if cloud_provider and not isinstance(cloud_provider, str):
            raise TypeError("Expected argument 'cloud_provider' to be a str")
        pulumi.set(__self__, "cloud_provider", cloud_provider)
        if credentials_id and not isinstance(credentials_id, str):
            raise TypeError("Expected argument 'credentials_id' to be a str")
        pulumi.set(__self__, "credentials_id", credentials_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if disk_size and not isinstance(disk_size, int):
            raise TypeError("Expected argument 'disk_size' to be a int")
        pulumi.set(__self__, "disk_size", disk_size)
        if features and not isinstance(features, dict):
            raise TypeError("Expected argument 'features' to be a dict")
        pulumi.set(__self__, "features", features)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if kubernetes_mode and not isinstance(kubernetes_mode, str):
            raise TypeError("Expected argument 'kubernetes_mode' to be a str")
        pulumi.set(__self__, "kubernetes_mode", kubernetes_mode)
        if max_running_nodes and not isinstance(max_running_nodes, int):
            raise TypeError("Expected argument 'max_running_nodes' to be a int")
        pulumi.set(__self__, "max_running_nodes", max_running_nodes)
        if min_running_nodes and not isinstance(min_running_nodes, int):
            raise TypeError("Expected argument 'min_running_nodes' to be a int")
        pulumi.set(__self__, "min_running_nodes", min_running_nodes)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if routing_tables and not isinstance(routing_tables, list):
            raise TypeError("Expected argument 'routing_tables' to be a list")
        pulumi.set(__self__, "routing_tables", routing_tables)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="advancedSettingsJson")
    def advanced_settings_json(self) -> str:
        return pulumi.get(self, "advanced_settings_json")

    @property
    @pulumi.getter(name="cloudProvider")
    def cloud_provider(self) -> str:
        return pulumi.get(self, "cloud_provider")

    @property
    @pulumi.getter(name="credentialsId")
    def credentials_id(self) -> str:
        return pulumi.get(self, "credentials_id")

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> int:
        return pulumi.get(self, "disk_size")

    @property
    @pulumi.getter
    def features(self) -> 'outputs.GetClusterFeaturesResult':
        return pulumi.get(self, "features")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> str:
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="kubernetesMode")
    def kubernetes_mode(self) -> str:
        return pulumi.get(self, "kubernetes_mode")

    @property
    @pulumi.getter(name="maxRunningNodes")
    def max_running_nodes(self) -> int:
        return pulumi.get(self, "max_running_nodes")

    @property
    @pulumi.getter(name="minRunningNodes")
    def min_running_nodes(self) -> int:
        return pulumi.get(self, "min_running_nodes")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def region(self) -> str:
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="routingTables")
    def routing_tables(self) -> Sequence['outputs.GetClusterRoutingTableResult']:
        return pulumi.get(self, "routing_tables")

    @property
    @pulumi.getter
    def state(self) -> str:
        return pulumi.get(self, "state")


class AwaitableGetClusterResult(GetClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClusterResult(
            advanced_settings_json=self.advanced_settings_json,
            cloud_provider=self.cloud_provider,
            credentials_id=self.credentials_id,
            description=self.description,
            disk_size=self.disk_size,
            features=self.features,
            id=self.id,
            instance_type=self.instance_type,
            kubernetes_mode=self.kubernetes_mode,
            max_running_nodes=self.max_running_nodes,
            min_running_nodes=self.min_running_nodes,
            name=self.name,
            organization_id=self.organization_id,
            region=self.region,
            routing_tables=self.routing_tables,
            state=self.state)


def get_cluster(advanced_settings_json: Optional[str] = None,
                description: Optional[str] = None,
                disk_size: Optional[int] = None,
                features: Optional[pulumi.InputType['GetClusterFeaturesArgs']] = None,
                id: Optional[str] = None,
                kubernetes_mode: Optional[str] = None,
                max_running_nodes: Optional[int] = None,
                min_running_nodes: Optional[int] = None,
                organization_id: Optional[str] = None,
                routing_tables: Optional[Sequence[pulumi.InputType['GetClusterRoutingTableArgs']]] = None,
                state: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClusterResult:
    """
    ## # Cluster (Data Source)

    Provides a Qovery cluster resource. This can be used to create and manage Qovery cluster.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_cluster = qovery.get_cluster(id="<cluster_id>",
        organization_id="<organization_id>")
    ```
    """
    __args__ = dict()
    __args__['advancedSettingsJson'] = advanced_settings_json
    __args__['description'] = description
    __args__['diskSize'] = disk_size
    __args__['features'] = features
    __args__['id'] = id
    __args__['kubernetesMode'] = kubernetes_mode
    __args__['maxRunningNodes'] = max_running_nodes
    __args__['minRunningNodes'] = min_running_nodes
    __args__['organizationId'] = organization_id
    __args__['routingTables'] = routing_tables
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getCluster:getCluster', __args__, opts=opts, typ=GetClusterResult).value

    return AwaitableGetClusterResult(
        advanced_settings_json=pulumi.get(__ret__, 'advanced_settings_json'),
        cloud_provider=pulumi.get(__ret__, 'cloud_provider'),
        credentials_id=pulumi.get(__ret__, 'credentials_id'),
        description=pulumi.get(__ret__, 'description'),
        disk_size=pulumi.get(__ret__, 'disk_size'),
        features=pulumi.get(__ret__, 'features'),
        id=pulumi.get(__ret__, 'id'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        kubernetes_mode=pulumi.get(__ret__, 'kubernetes_mode'),
        max_running_nodes=pulumi.get(__ret__, 'max_running_nodes'),
        min_running_nodes=pulumi.get(__ret__, 'min_running_nodes'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        region=pulumi.get(__ret__, 'region'),
        routing_tables=pulumi.get(__ret__, 'routing_tables'),
        state=pulumi.get(__ret__, 'state'))


@_utilities.lift_output_func(get_cluster)
def get_cluster_output(advanced_settings_json: Optional[pulumi.Input[Optional[str]]] = None,
                       description: Optional[pulumi.Input[Optional[str]]] = None,
                       disk_size: Optional[pulumi.Input[Optional[int]]] = None,
                       features: Optional[pulumi.Input[Optional[pulumi.InputType['GetClusterFeaturesArgs']]]] = None,
                       id: Optional[pulumi.Input[str]] = None,
                       kubernetes_mode: Optional[pulumi.Input[Optional[str]]] = None,
                       max_running_nodes: Optional[pulumi.Input[Optional[int]]] = None,
                       min_running_nodes: Optional[pulumi.Input[Optional[int]]] = None,
                       organization_id: Optional[pulumi.Input[str]] = None,
                       routing_tables: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetClusterRoutingTableArgs']]]]] = None,
                       state: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetClusterResult]:
    """
    ## # Cluster (Data Source)

    Provides a Qovery cluster resource. This can be used to create and manage Qovery cluster.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_cluster = qovery.get_cluster(id="<cluster_id>",
        organization_id="<organization_id>")
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['JobArgs', 'Job']

@pulumi.input_type
class JobArgs:
    def __init__(__self__, *,
                 environment_id: pulumi.Input[str],
                 healthchecks: pulumi.Input['JobHealthchecksArgs'],
                 schedule: pulumi.Input['JobScheduleArgs'],
                 advanced_settings_json: Optional[pulumi.Input[str]] = None,
                 auto_deploy: Optional[pulumi.Input[bool]] = None,
                 auto_preview: Optional[pulumi.Input[bool]] = None,
                 cpu: Optional[pulumi.Input[int]] = None,
                 deployment_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input['JobDeploymentRestrictionArgs']]]] = None,
                 deployment_stage_id: Optional[pulumi.Input[str]] = None,
                 environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableAliasArgs']]]] = None,
                 environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableOverrideArgs']]]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableArgs']]]] = None,
                 max_duration_seconds: Optional[pulumi.Input[int]] = None,
                 max_nb_restart: Optional[pulumi.Input[int]] = None,
                 memory: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretAliasArgs']]]] = None,
                 secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretOverrideArgs']]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretArgs']]]] = None,
                 source: Optional[pulumi.Input['JobSourceArgs']] = None):
        """
        The set of arguments for constructing a Job resource.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input['JobHealthchecksArgs'] healthchecks: Configuration for the healthchecks that are going to be executed against your service
        :param pulumi.Input['JobScheduleArgs'] schedule: Job's schedule.
        :param pulumi.Input[str] advanced_settings_json: Advanced settings.
        :param pulumi.Input[bool] auto_deploy: Specify if the job will be automatically updated after receiving a new image tag.
        :param pulumi.Input[bool] auto_preview: Specify if the environment preview option is activated or not for this job.
        :param pulumi.Input[int] cpu: CPU of the job in millicores (m) [1000m = 1 CPU]. - Must be: `>= 10`. - Default: `500`.
        :param pulumi.Input[Sequence[pulumi.Input['JobDeploymentRestrictionArgs']]] deployment_restrictions: List of deployment restrictions
        :param pulumi.Input[str] deployment_stage_id: Id of the deployment stage.
        :param pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableAliasArgs']]] environment_variable_aliases: List of environment variable aliases linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableOverrideArgs']]] environment_variable_overrides: List of environment variable overrides linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableArgs']]] environment_variables: List of environment variables linked to this job.
        :param pulumi.Input[int] max_duration_seconds: Job's max duration in seconds. - Must be: `>= 0`. - Default: `300`.
        :param pulumi.Input[int] max_nb_restart: Job's max number of restarts. - Must be: `>= 0`. - Default: `0`.
        :param pulumi.Input[int] memory: RAM of the job in MB [1024MB = 1GB]. - Must be: `>= 1`. - Default: `512`.
        :param pulumi.Input[str] name: Name of the job.
        :param pulumi.Input[int] port: Job's probes port. - Must be: `>= 1` and `<= 65535`.
        :param pulumi.Input[Sequence[pulumi.Input['JobSecretAliasArgs']]] secret_aliases: List of secret aliases linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobSecretOverrideArgs']]] secret_overrides: List of secret overrides linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobSecretArgs']]] secrets: List of secrets linked to this job.
        :param pulumi.Input['JobSourceArgs'] source: Job's source.
        """
        pulumi.set(__self__, "environment_id", environment_id)
        pulumi.set(__self__, "healthchecks", healthchecks)
        pulumi.set(__self__, "schedule", schedule)
        if advanced_settings_json is not None:
            pulumi.set(__self__, "advanced_settings_json", advanced_settings_json)
        if auto_deploy is not None:
            pulumi.set(__self__, "auto_deploy", auto_deploy)
        if auto_preview is not None:
            pulumi.set(__self__, "auto_preview", auto_preview)
        if cpu is not None:
            pulumi.set(__self__, "cpu", cpu)
        if deployment_restrictions is not None:
            pulumi.set(__self__, "deployment_restrictions", deployment_restrictions)
        if deployment_stage_id is not None:
            pulumi.set(__self__, "deployment_stage_id", deployment_stage_id)
        if environment_variable_aliases is not None:
            pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides is not None:
            pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if max_duration_seconds is not None:
            pulumi.set(__self__, "max_duration_seconds", max_duration_seconds)
        if max_nb_restart is not None:
            pulumi.set(__self__, "max_nb_restart", max_nb_restart)
        if memory is not None:
            pulumi.set(__self__, "memory", memory)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if secret_aliases is not None:
            pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides is not None:
            pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets is not None:
            pulumi.set(__self__, "secrets", secrets)
        if source is not None:
            pulumi.set(__self__, "source", source)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Input[str]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter
    def healthchecks(self) -> pulumi.Input['JobHealthchecksArgs']:
        """
        Configuration for the healthchecks that are going to be executed against your service
        """
        return pulumi.get(self, "healthchecks")

    @healthchecks.setter
    def healthchecks(self, value: pulumi.Input['JobHealthchecksArgs']):
        pulumi.set(self, "healthchecks", value)

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Input['JobScheduleArgs']:
        """
        Job's schedule.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: pulumi.Input['JobScheduleArgs']):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="advancedSettingsJson")
    def advanced_settings_json(self) -> Optional[pulumi.Input[str]]:
        """
        Advanced settings.
        """
        return pulumi.get(self, "advanced_settings_json")

    @advanced_settings_json.setter
    def advanced_settings_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "advanced_settings_json", value)

    @property
    @pulumi.getter(name="autoDeploy")
    def auto_deploy(self) -> Optional[pulumi.Input[bool]]:
        """
        Specify if the job will be automatically updated after receiving a new image tag.
        """
        return pulumi.get(self, "auto_deploy")

    @auto_deploy.setter
    def auto_deploy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_deploy", value)

    @property
    @pulumi.getter(name="autoPreview")
    def auto_preview(self) -> Optional[pulumi.Input[bool]]:
        """
        Specify if the environment preview option is activated or not for this job.
        """
        return pulumi.get(self, "auto_preview")

    @auto_preview.setter
    def auto_preview(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_preview", value)

    @property
    @pulumi.getter
    def cpu(self) -> Optional[pulumi.Input[int]]:
        """
        CPU of the job in millicores (m) [1000m = 1 CPU]. - Must be: `>= 10`. - Default: `500`.
        """
        return pulumi.get(self, "cpu")

    @cpu.setter
    def cpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cpu", value)

    @property
    @pulumi.getter(name="deploymentRestrictions")
    def deployment_restrictions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobDeploymentRestrictionArgs']]]]:
        """
        List of deployment restrictions
        """
        return pulumi.get(self, "deployment_restrictions")

    @deployment_restrictions.setter
    def deployment_restrictions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobDeploymentRestrictionArgs']]]]):
        pulumi.set(self, "deployment_restrictions", value)

    @property
    @pulumi.getter(name="deploymentStageId")
    def deployment_stage_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the deployment stage.
        """
        return pulumi.get(self, "deployment_stage_id")

    @deployment_stage_id.setter
    def deployment_stage_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_stage_id", value)

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableAliasArgs']]]]:
        """
        List of environment variable aliases linked to this job.
        """
        return pulumi.get(self, "environment_variable_aliases")

    @environment_variable_aliases.setter
    def environment_variable_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableAliasArgs']]]]):
        pulumi.set(self, "environment_variable_aliases", value)

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableOverrideArgs']]]]:
        """
        List of environment variable overrides linked to this job.
        """
        return pulumi.get(self, "environment_variable_overrides")

    @environment_variable_overrides.setter
    def environment_variable_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableOverrideArgs']]]]):
        pulumi.set(self, "environment_variable_overrides", value)

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableArgs']]]]:
        """
        List of environment variables linked to this job.
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableArgs']]]]):
        pulumi.set(self, "environment_variables", value)

    @property
    @pulumi.getter(name="maxDurationSeconds")
    def max_duration_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        Job's max duration in seconds. - Must be: `>= 0`. - Default: `300`.
        """
        return pulumi.get(self, "max_duration_seconds")

    @max_duration_seconds.setter
    def max_duration_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_duration_seconds", value)

    @property
    @pulumi.getter(name="maxNbRestart")
    def max_nb_restart(self) -> Optional[pulumi.Input[int]]:
        """
        Job's max number of restarts. - Must be: `>= 0`. - Default: `0`.
        """
        return pulumi.get(self, "max_nb_restart")

    @max_nb_restart.setter
    def max_nb_restart(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_nb_restart", value)

    @property
    @pulumi.getter
    def memory(self) -> Optional[pulumi.Input[int]]:
        """
        RAM of the job in MB [1024MB = 1GB]. - Must be: `>= 1`. - Default: `512`.
        """
        return pulumi.get(self, "memory")

    @memory.setter
    def memory(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the job.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        Job's probes port. - Must be: `>= 1` and `<= 65535`.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretAliasArgs']]]]:
        """
        List of secret aliases linked to this job.
        """
        return pulumi.get(self, "secret_aliases")

    @secret_aliases.setter
    def secret_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretAliasArgs']]]]):
        pulumi.set(self, "secret_aliases", value)

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretOverrideArgs']]]]:
        """
        List of secret overrides linked to this job.
        """
        return pulumi.get(self, "secret_overrides")

    @secret_overrides.setter
    def secret_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretOverrideArgs']]]]):
        pulumi.set(self, "secret_overrides", value)

    @property
    @pulumi.getter
    def secrets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretArgs']]]]:
        """
        List of secrets linked to this job.
        """
        return pulumi.get(self, "secrets")

    @secrets.setter
    def secrets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretArgs']]]]):
        pulumi.set(self, "secrets", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input['JobSourceArgs']]:
        """
        Job's source.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input['JobSourceArgs']]):
        pulumi.set(self, "source", value)


@pulumi.input_type
class _JobState:
    def __init__(__self__, *,
                 advanced_settings_json: Optional[pulumi.Input[str]] = None,
                 auto_deploy: Optional[pulumi.Input[bool]] = None,
                 auto_preview: Optional[pulumi.Input[bool]] = None,
                 built_in_environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['JobBuiltInEnvironmentVariableArgs']]]] = None,
                 cpu: Optional[pulumi.Input[int]] = None,
                 deployment_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input['JobDeploymentRestrictionArgs']]]] = None,
                 deployment_stage_id: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableAliasArgs']]]] = None,
                 environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableOverrideArgs']]]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableArgs']]]] = None,
                 external_host: Optional[pulumi.Input[str]] = None,
                 healthchecks: Optional[pulumi.Input['JobHealthchecksArgs']] = None,
                 internal_host: Optional[pulumi.Input[str]] = None,
                 max_duration_seconds: Optional[pulumi.Input[int]] = None,
                 max_nb_restart: Optional[pulumi.Input[int]] = None,
                 memory: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 schedule: Optional[pulumi.Input['JobScheduleArgs']] = None,
                 secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretAliasArgs']]]] = None,
                 secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretOverrideArgs']]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretArgs']]]] = None,
                 source: Optional[pulumi.Input['JobSourceArgs']] = None):
        """
        Input properties used for looking up and filtering Job resources.
        :param pulumi.Input[str] advanced_settings_json: Advanced settings.
        :param pulumi.Input[bool] auto_deploy: Specify if the job will be automatically updated after receiving a new image tag.
        :param pulumi.Input[bool] auto_preview: Specify if the environment preview option is activated or not for this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobBuiltInEnvironmentVariableArgs']]] built_in_environment_variables: List of built-in environment variables linked to this job.
        :param pulumi.Input[int] cpu: CPU of the job in millicores (m) [1000m = 1 CPU]. - Must be: `>= 10`. - Default: `500`.
        :param pulumi.Input[Sequence[pulumi.Input['JobDeploymentRestrictionArgs']]] deployment_restrictions: List of deployment restrictions
        :param pulumi.Input[str] deployment_stage_id: Id of the deployment stage.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableAliasArgs']]] environment_variable_aliases: List of environment variable aliases linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableOverrideArgs']]] environment_variable_overrides: List of environment variable overrides linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableArgs']]] environment_variables: List of environment variables linked to this job.
        :param pulumi.Input[str] external_host: The job external FQDN host [NOTE: only if your job is using a publicly accessible port].
        :param pulumi.Input['JobHealthchecksArgs'] healthchecks: Configuration for the healthchecks that are going to be executed against your service
        :param pulumi.Input[str] internal_host: The job internal host.
        :param pulumi.Input[int] max_duration_seconds: Job's max duration in seconds. - Must be: `>= 0`. - Default: `300`.
        :param pulumi.Input[int] max_nb_restart: Job's max number of restarts. - Must be: `>= 0`. - Default: `0`.
        :param pulumi.Input[int] memory: RAM of the job in MB [1024MB = 1GB]. - Must be: `>= 1`. - Default: `512`.
        :param pulumi.Input[str] name: Name of the job.
        :param pulumi.Input[int] port: Job's probes port. - Must be: `>= 1` and `<= 65535`.
        :param pulumi.Input['JobScheduleArgs'] schedule: Job's schedule.
        :param pulumi.Input[Sequence[pulumi.Input['JobSecretAliasArgs']]] secret_aliases: List of secret aliases linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobSecretOverrideArgs']]] secret_overrides: List of secret overrides linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input['JobSecretArgs']]] secrets: List of secrets linked to this job.
        :param pulumi.Input['JobSourceArgs'] source: Job's source.
        """
        if advanced_settings_json is not None:
            pulumi.set(__self__, "advanced_settings_json", advanced_settings_json)
        if auto_deploy is not None:
            pulumi.set(__self__, "auto_deploy", auto_deploy)
        if auto_preview is not None:
            pulumi.set(__self__, "auto_preview", auto_preview)
        if built_in_environment_variables is not None:
            pulumi.set(__self__, "built_in_environment_variables", built_in_environment_variables)
        if cpu is not None:
            pulumi.set(__self__, "cpu", cpu)
        if deployment_restrictions is not None:
            pulumi.set(__self__, "deployment_restrictions", deployment_restrictions)
        if deployment_stage_id is not None:
            pulumi.set(__self__, "deployment_stage_id", deployment_stage_id)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)
        if environment_variable_aliases is not None:
            pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides is not None:
            pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if external_host is not None:
            pulumi.set(__self__, "external_host", external_host)
        if healthchecks is not None:
            pulumi.set(__self__, "healthchecks", healthchecks)
        if internal_host is not None:
            pulumi.set(__self__, "internal_host", internal_host)
        if max_duration_seconds is not None:
            pulumi.set(__self__, "max_duration_seconds", max_duration_seconds)
        if max_nb_restart is not None:
            pulumi.set(__self__, "max_nb_restart", max_nb_restart)
        if memory is not None:
            pulumi.set(__self__, "memory", memory)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if secret_aliases is not None:
            pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides is not None:
            pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets is not None:
            pulumi.set(__self__, "secrets", secrets)
        if source is not None:
            pulumi.set(__self__, "source", source)

    @property
    @pulumi.getter(name="advancedSettingsJson")
    def advanced_settings_json(self) -> Optional[pulumi.Input[str]]:
        """
        Advanced settings.
        """
        return pulumi.get(self, "advanced_settings_json")

    @advanced_settings_json.setter
    def advanced_settings_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "advanced_settings_json", value)

    @property
    @pulumi.getter(name="autoDeploy")
    def auto_deploy(self) -> Optional[pulumi.Input[bool]]:
        """
        Specify if the job will be automatically updated after receiving a new image tag.
        """
        return pulumi.get(self, "auto_deploy")

    @auto_deploy.setter
    def auto_deploy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_deploy", value)

    @property
    @pulumi.getter(name="autoPreview")
    def auto_preview(self) -> Optional[pulumi.Input[bool]]:
        """
        Specify if the environment preview option is activated or not for this job.
        """
        return pulumi.get(self, "auto_preview")

    @auto_preview.setter
    def auto_preview(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_preview", value)

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobBuiltInEnvironmentVariableArgs']]]]:
        """
        List of built-in environment variables linked to this job.
        """
        return pulumi.get(self, "built_in_environment_variables")

    @built_in_environment_variables.setter
    def built_in_environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobBuiltInEnvironmentVariableArgs']]]]):
        pulumi.set(self, "built_in_environment_variables", value)

    @property
    @pulumi.getter
    def cpu(self) -> Optional[pulumi.Input[int]]:
        """
        CPU of the job in millicores (m) [1000m = 1 CPU]. - Must be: `>= 10`. - Default: `500`.
        """
        return pulumi.get(self, "cpu")

    @cpu.setter
    def cpu(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cpu", value)

    @property
    @pulumi.getter(name="deploymentRestrictions")
    def deployment_restrictions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobDeploymentRestrictionArgs']]]]:
        """
        List of deployment restrictions
        """
        return pulumi.get(self, "deployment_restrictions")

    @deployment_restrictions.setter
    def deployment_restrictions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobDeploymentRestrictionArgs']]]]):
        pulumi.set(self, "deployment_restrictions", value)

    @property
    @pulumi.getter(name="deploymentStageId")
    def deployment_stage_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the deployment stage.
        """
        return pulumi.get(self, "deployment_stage_id")

    @deployment_stage_id.setter
    def deployment_stage_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_stage_id", value)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableAliasArgs']]]]:
        """
        List of environment variable aliases linked to this job.
        """
        return pulumi.get(self, "environment_variable_aliases")

    @environment_variable_aliases.setter
    def environment_variable_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableAliasArgs']]]]):
        pulumi.set(self, "environment_variable_aliases", value)

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableOverrideArgs']]]]:
        """
        List of environment variable overrides linked to this job.
        """
        return pulumi.get(self, "environment_variable_overrides")

    @environment_variable_overrides.setter
    def environment_variable_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableOverrideArgs']]]]):
        pulumi.set(self, "environment_variable_overrides", value)

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableArgs']]]]:
        """
        List of environment variables linked to this job.
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobEnvironmentVariableArgs']]]]):
        pulumi.set(self, "environment_variables", value)

    @property
    @pulumi.getter(name="externalHost")
    def external_host(self) -> Optional[pulumi.Input[str]]:
        """
        The job external FQDN host [NOTE: only if your job is using a publicly accessible port].
        """
        return pulumi.get(self, "external_host")

    @external_host.setter
    def external_host(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_host", value)

    @property
    @pulumi.getter
    def healthchecks(self) -> Optional[pulumi.Input['JobHealthchecksArgs']]:
        """
        Configuration for the healthchecks that are going to be executed against your service
        """
        return pulumi.get(self, "healthchecks")

    @healthchecks.setter
    def healthchecks(self, value: Optional[pulumi.Input['JobHealthchecksArgs']]):
        pulumi.set(self, "healthchecks", value)

    @property
    @pulumi.getter(name="internalHost")
    def internal_host(self) -> Optional[pulumi.Input[str]]:
        """
        The job internal host.
        """
        return pulumi.get(self, "internal_host")

    @internal_host.setter
    def internal_host(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internal_host", value)

    @property
    @pulumi.getter(name="maxDurationSeconds")
    def max_duration_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        Job's max duration in seconds. - Must be: `>= 0`. - Default: `300`.
        """
        return pulumi.get(self, "max_duration_seconds")

    @max_duration_seconds.setter
    def max_duration_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_duration_seconds", value)

    @property
    @pulumi.getter(name="maxNbRestart")
    def max_nb_restart(self) -> Optional[pulumi.Input[int]]:
        """
        Job's max number of restarts. - Must be: `>= 0`. - Default: `0`.
        """
        return pulumi.get(self, "max_nb_restart")

    @max_nb_restart.setter
    def max_nb_restart(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_nb_restart", value)

    @property
    @pulumi.getter
    def memory(self) -> Optional[pulumi.Input[int]]:
        """
        RAM of the job in MB [1024MB = 1GB]. - Must be: `>= 1`. - Default: `512`.
        """
        return pulumi.get(self, "memory")

    @memory.setter
    def memory(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "memory", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the job.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        Job's probes port. - Must be: `>= 1` and `<= 65535`.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['JobScheduleArgs']]:
        """
        Job's schedule.
        """
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['JobScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretAliasArgs']]]]:
        """
        List of secret aliases linked to this job.
        """
        return pulumi.get(self, "secret_aliases")

    @secret_aliases.setter
    def secret_aliases(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretAliasArgs']]]]):
        pulumi.set(self, "secret_aliases", value)

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretOverrideArgs']]]]:
        """
        List of secret overrides linked to this job.
        """
        return pulumi.get(self, "secret_overrides")

    @secret_overrides.setter
    def secret_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretOverrideArgs']]]]):
        pulumi.set(self, "secret_overrides", value)

    @property
    @pulumi.getter
    def secrets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretArgs']]]]:
        """
        List of secrets linked to this job.
        """
        return pulumi.get(self, "secrets")

    @secrets.setter
    def secrets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['JobSecretArgs']]]]):
        pulumi.set(self, "secrets", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input['JobSourceArgs']]:
        """
        Job's source.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input['JobSourceArgs']]):
        pulumi.set(self, "source", value)


class Job(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advanced_settings_json: Optional[pulumi.Input[str]] = None,
                 auto_deploy: Optional[pulumi.Input[bool]] = None,
                 auto_preview: Optional[pulumi.Input[bool]] = None,
                 cpu: Optional[pulumi.Input[int]] = None,
                 deployment_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobDeploymentRestrictionArgs']]]]] = None,
                 deployment_stage_id: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableAliasArgs']]]]] = None,
                 environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableOverrideArgs']]]]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableArgs']]]]] = None,
                 healthchecks: Optional[pulumi.Input[pulumi.InputType['JobHealthchecksArgs']]] = None,
                 max_duration_seconds: Optional[pulumi.Input[int]] = None,
                 max_nb_restart: Optional[pulumi.Input[int]] = None,
                 memory: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 schedule: Optional[pulumi.Input[pulumi.InputType['JobScheduleArgs']]] = None,
                 secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretAliasArgs']]]]] = None,
                 secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretOverrideArgs']]]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretArgs']]]]] = None,
                 source: Optional[pulumi.Input[pulumi.InputType['JobSourceArgs']]] = None,
                 __props__=None):
        """
        ## # Job (Resource)

        Provides a Qovery job resource. This can be used to create and manage Qovery job registry.

        ## Import

        ```sh
         $ pulumi import qovery:index/job:Job my_job "<job_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] advanced_settings_json: Advanced settings.
        :param pulumi.Input[bool] auto_deploy: Specify if the job will be automatically updated after receiving a new image tag.
        :param pulumi.Input[bool] auto_preview: Specify if the environment preview option is activated or not for this job.
        :param pulumi.Input[int] cpu: CPU of the job in millicores (m) [1000m = 1 CPU]. - Must be: `>= 10`. - Default: `500`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobDeploymentRestrictionArgs']]]] deployment_restrictions: List of deployment restrictions
        :param pulumi.Input[str] deployment_stage_id: Id of the deployment stage.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableAliasArgs']]]] environment_variable_aliases: List of environment variable aliases linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableOverrideArgs']]]] environment_variable_overrides: List of environment variable overrides linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableArgs']]]] environment_variables: List of environment variables linked to this job.
        :param pulumi.Input[pulumi.InputType['JobHealthchecksArgs']] healthchecks: Configuration for the healthchecks that are going to be executed against your service
        :param pulumi.Input[int] max_duration_seconds: Job's max duration in seconds. - Must be: `>= 0`. - Default: `300`.
        :param pulumi.Input[int] max_nb_restart: Job's max number of restarts. - Must be: `>= 0`. - Default: `0`.
        :param pulumi.Input[int] memory: RAM of the job in MB [1024MB = 1GB]. - Must be: `>= 1`. - Default: `512`.
        :param pulumi.Input[str] name: Name of the job.
        :param pulumi.Input[int] port: Job's probes port. - Must be: `>= 1` and `<= 65535`.
        :param pulumi.Input[pulumi.InputType['JobScheduleArgs']] schedule: Job's schedule.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretAliasArgs']]]] secret_aliases: List of secret aliases linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretOverrideArgs']]]] secret_overrides: List of secret overrides linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretArgs']]]] secrets: List of secrets linked to this job.
        :param pulumi.Input[pulumi.InputType['JobSourceArgs']] source: Job's source.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: JobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # Job (Resource)

        Provides a Qovery job resource. This can be used to create and manage Qovery job registry.

        ## Import

        ```sh
         $ pulumi import qovery:index/job:Job my_job "<job_id>"
        ```

        :param str resource_name: The name of the resource.
        :param JobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(JobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 advanced_settings_json: Optional[pulumi.Input[str]] = None,
                 auto_deploy: Optional[pulumi.Input[bool]] = None,
                 auto_preview: Optional[pulumi.Input[bool]] = None,
                 cpu: Optional[pulumi.Input[int]] = None,
                 deployment_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobDeploymentRestrictionArgs']]]]] = None,
                 deployment_stage_id: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableAliasArgs']]]]] = None,
                 environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableOverrideArgs']]]]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableArgs']]]]] = None,
                 healthchecks: Optional[pulumi.Input[pulumi.InputType['JobHealthchecksArgs']]] = None,
                 max_duration_seconds: Optional[pulumi.Input[int]] = None,
                 max_nb_restart: Optional[pulumi.Input[int]] = None,
                 memory: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 schedule: Optional[pulumi.Input[pulumi.InputType['JobScheduleArgs']]] = None,
                 secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretAliasArgs']]]]] = None,
                 secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretOverrideArgs']]]]] = None,
                 secrets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretArgs']]]]] = None,
                 source: Optional[pulumi.Input[pulumi.InputType['JobSourceArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = JobArgs.__new__(JobArgs)

            __props__.__dict__["advanced_settings_json"] = advanced_settings_json
            __props__.__dict__["auto_deploy"] = auto_deploy
            __props__.__dict__["auto_preview"] = auto_preview
            __props__.__dict__["cpu"] = cpu
            __props__.__dict__["deployment_restrictions"] = deployment_restrictions
            __props__.__dict__["deployment_stage_id"] = deployment_stage_id
            if environment_id is None and not opts.urn:
                raise TypeError("Missing required property 'environment_id'")
            __props__.__dict__["environment_id"] = environment_id
            __props__.__dict__["environment_variable_aliases"] = environment_variable_aliases
            __props__.__dict__["environment_variable_overrides"] = environment_variable_overrides
            __props__.__dict__["environment_variables"] = environment_variables
            if healthchecks is None and not opts.urn:
                raise TypeError("Missing required property 'healthchecks'")
            __props__.__dict__["healthchecks"] = healthchecks
            __props__.__dict__["max_duration_seconds"] = max_duration_seconds
            __props__.__dict__["max_nb_restart"] = max_nb_restart
            __props__.__dict__["memory"] = memory
            __props__.__dict__["name"] = name
            __props__.__dict__["port"] = port
            if schedule is None and not opts.urn:
                raise TypeError("Missing required property 'schedule'")
            __props__.__dict__["schedule"] = schedule
            __props__.__dict__["secret_aliases"] = secret_aliases
            __props__.__dict__["secret_overrides"] = secret_overrides
            __props__.__dict__["secrets"] = secrets
            __props__.__dict__["source"] = source
            __props__.__dict__["built_in_environment_variables"] = None
            __props__.__dict__["external_host"] = None
            __props__.__dict__["internal_host"] = None
        super(Job, __self__).__init__(
            'qovery:index/job:Job',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            advanced_settings_json: Optional[pulumi.Input[str]] = None,
            auto_deploy: Optional[pulumi.Input[bool]] = None,
            auto_preview: Optional[pulumi.Input[bool]] = None,
            built_in_environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobBuiltInEnvironmentVariableArgs']]]]] = None,
            cpu: Optional[pulumi.Input[int]] = None,
            deployment_restrictions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobDeploymentRestrictionArgs']]]]] = None,
            deployment_stage_id: Optional[pulumi.Input[str]] = None,
            environment_id: Optional[pulumi.Input[str]] = None,
            environment_variable_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableAliasArgs']]]]] = None,
            environment_variable_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableOverrideArgs']]]]] = None,
            environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableArgs']]]]] = None,
            external_host: Optional[pulumi.Input[str]] = None,
            healthchecks: Optional[pulumi.Input[pulumi.InputType['JobHealthchecksArgs']]] = None,
            internal_host: Optional[pulumi.Input[str]] = None,
            max_duration_seconds: Optional[pulumi.Input[int]] = None,
            max_nb_restart: Optional[pulumi.Input[int]] = None,
            memory: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            port: Optional[pulumi.Input[int]] = None,
            schedule: Optional[pulumi.Input[pulumi.InputType['JobScheduleArgs']]] = None,
            secret_aliases: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretAliasArgs']]]]] = None,
            secret_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretOverrideArgs']]]]] = None,
            secrets: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretArgs']]]]] = None,
            source: Optional[pulumi.Input[pulumi.InputType['JobSourceArgs']]] = None) -> 'Job':
        """
        Get an existing Job resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] advanced_settings_json: Advanced settings.
        :param pulumi.Input[bool] auto_deploy: Specify if the job will be automatically updated after receiving a new image tag.
        :param pulumi.Input[bool] auto_preview: Specify if the environment preview option is activated or not for this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobBuiltInEnvironmentVariableArgs']]]] built_in_environment_variables: List of built-in environment variables linked to this job.
        :param pulumi.Input[int] cpu: CPU of the job in millicores (m) [1000m = 1 CPU]. - Must be: `>= 10`. - Default: `500`.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobDeploymentRestrictionArgs']]]] deployment_restrictions: List of deployment restrictions
        :param pulumi.Input[str] deployment_stage_id: Id of the deployment stage.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableAliasArgs']]]] environment_variable_aliases: List of environment variable aliases linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableOverrideArgs']]]] environment_variable_overrides: List of environment variable overrides linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobEnvironmentVariableArgs']]]] environment_variables: List of environment variables linked to this job.
        :param pulumi.Input[str] external_host: The job external FQDN host [NOTE: only if your job is using a publicly accessible port].
        :param pulumi.Input[pulumi.InputType['JobHealthchecksArgs']] healthchecks: Configuration for the healthchecks that are going to be executed against your service
        :param pulumi.Input[str] internal_host: The job internal host.
        :param pulumi.Input[int] max_duration_seconds: Job's max duration in seconds. - Must be: `>= 0`. - Default: `300`.
        :param pulumi.Input[int] max_nb_restart: Job's max number of restarts. - Must be: `>= 0`. - Default: `0`.
        :param pulumi.Input[int] memory: RAM of the job in MB [1024MB = 1GB]. - Must be: `>= 1`. - Default: `512`.
        :param pulumi.Input[str] name: Name of the job.
        :param pulumi.Input[int] port: Job's probes port. - Must be: `>= 1` and `<= 65535`.
        :param pulumi.Input[pulumi.InputType['JobScheduleArgs']] schedule: Job's schedule.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretAliasArgs']]]] secret_aliases: List of secret aliases linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretOverrideArgs']]]] secret_overrides: List of secret overrides linked to this job.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['JobSecretArgs']]]] secrets: List of secrets linked to this job.
        :param pulumi.Input[pulumi.InputType['JobSourceArgs']] source: Job's source.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _JobState.__new__(_JobState)

        __props__.__dict__["advanced_settings_json"] = advanced_settings_json
        __props__.__dict__["auto_deploy"] = auto_deploy
        __props__.__dict__["auto_preview"] = auto_preview
        __props__.__dict__["built_in_environment_variables"] = built_in_environment_variables
        __props__.__dict__["cpu"] = cpu
        __props__.__dict__["deployment_restrictions"] = deployment_restrictions
        __props__.__dict__["deployment_stage_id"] = deployment_stage_id
        __props__.__dict__["environment_id"] = environment_id
        __props__.__dict__["environment_variable_aliases"] = environment_variable_aliases
        __props__.__dict__["environment_variable_overrides"] = environment_variable_overrides
        __props__.__dict__["environment_variables"] = environment_variables
        __props__.__dict__["external_host"] = external_host
        __props__.__dict__["healthchecks"] = healthchecks
        __props__.__dict__["internal_host"] = internal_host
        __props__.__dict__["max_duration_seconds"] = max_duration_seconds
        __props__.__dict__["max_nb_restart"] = max_nb_restart
        __props__.__dict__["memory"] = memory
        __props__.__dict__["name"] = name
        __props__.__dict__["port"] = port
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["secret_aliases"] = secret_aliases
        __props__.__dict__["secret_overrides"] = secret_overrides
        __props__.__dict__["secrets"] = secrets
        __props__.__dict__["source"] = source
        return Job(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="advancedSettingsJson")
    def advanced_settings_json(self) -> pulumi.Output[str]:
        """
        Advanced settings.
        """
        return pulumi.get(self, "advanced_settings_json")

    @property
    @pulumi.getter(name="autoDeploy")
    def auto_deploy(self) -> pulumi.Output[bool]:
        """
        Specify if the job will be automatically updated after receiving a new image tag.
        """
        return pulumi.get(self, "auto_deploy")

    @property
    @pulumi.getter(name="autoPreview")
    def auto_preview(self) -> pulumi.Output[bool]:
        """
        Specify if the environment preview option is activated or not for this job.
        """
        return pulumi.get(self, "auto_preview")

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> pulumi.Output[Sequence['outputs.JobBuiltInEnvironmentVariable']]:
        """
        List of built-in environment variables linked to this job.
        """
        return pulumi.get(self, "built_in_environment_variables")

    @property
    @pulumi.getter
    def cpu(self) -> pulumi.Output[int]:
        """
        CPU of the job in millicores (m) [1000m = 1 CPU]. - Must be: `>= 10`. - Default: `500`.
        """
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter(name="deploymentRestrictions")
    def deployment_restrictions(self) -> pulumi.Output[Optional[Sequence['outputs.JobDeploymentRestriction']]]:
        """
        List of deployment restrictions
        """
        return pulumi.get(self, "deployment_restrictions")

    @property
    @pulumi.getter(name="deploymentStageId")
    def deployment_stage_id(self) -> pulumi.Output[str]:
        """
        Id of the deployment stage.
        """
        return pulumi.get(self, "deployment_stage_id")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Output[str]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> pulumi.Output[Optional[Sequence['outputs.JobEnvironmentVariableAlias']]]:
        """
        List of environment variable aliases linked to this job.
        """
        return pulumi.get(self, "environment_variable_aliases")

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> pulumi.Output[Optional[Sequence['outputs.JobEnvironmentVariableOverride']]]:
        """
        List of environment variable overrides linked to this job.
        """
        return pulumi.get(self, "environment_variable_overrides")

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> pulumi.Output[Optional[Sequence['outputs.JobEnvironmentVariable']]]:
        """
        List of environment variables linked to this job.
        """
        return pulumi.get(self, "environment_variables")

    @property
    @pulumi.getter(name="externalHost")
    def external_host(self) -> pulumi.Output[str]:
        """
        The job external FQDN host [NOTE: only if your job is using a publicly accessible port].
        """
        return pulumi.get(self, "external_host")

    @property
    @pulumi.getter
    def healthchecks(self) -> pulumi.Output['outputs.JobHealthchecks']:
        """
        Configuration for the healthchecks that are going to be executed against your service
        """
        return pulumi.get(self, "healthchecks")

    @property
    @pulumi.getter(name="internalHost")
    def internal_host(self) -> pulumi.Output[str]:
        """
        The job internal host.
        """
        return pulumi.get(self, "internal_host")

    @property
    @pulumi.getter(name="maxDurationSeconds")
    def max_duration_seconds(self) -> pulumi.Output[int]:
        """
        Job's max duration in seconds. - Must be: `>= 0`. - Default: `300`.
        """
        return pulumi.get(self, "max_duration_seconds")

    @property
    @pulumi.getter(name="maxNbRestart")
    def max_nb_restart(self) -> pulumi.Output[int]:
        """
        Job's max number of restarts. - Must be: `>= 0`. - Default: `0`.
        """
        return pulumi.get(self, "max_nb_restart")

    @property
    @pulumi.getter
    def memory(self) -> pulumi.Output[int]:
        """
        RAM of the job in MB [1024MB = 1GB]. - Must be: `>= 1`. - Default: `512`.
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the job.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[int]]:
        """
        Job's probes port. - Must be: `>= 1` and `<= 65535`.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def schedule(self) -> pulumi.Output['outputs.JobSchedule']:
        """
        Job's schedule.
        """
        return pulumi.get(self, "schedule")

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> pulumi.Output[Optional[Sequence['outputs.JobSecretAlias']]]:
        """
        List of secret aliases linked to this job.
        """
        return pulumi.get(self, "secret_aliases")

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> pulumi.Output[Optional[Sequence['outputs.JobSecretOverride']]]:
        """
        List of secret overrides linked to this job.
        """
        return pulumi.get(self, "secret_overrides")

    @property
    @pulumi.getter
    def secrets(self) -> pulumi.Output[Optional[Sequence['outputs.JobSecret']]]:
        """
        List of secrets linked to this job.
        """
        return pulumi.get(self, "secrets")

    @property
    @pulumi.getter
    def source(self) -> pulumi.Output[Optional['outputs.JobSource']]:
        """
        Job's source.
        """
        return pulumi.get(self, "source")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetProjectResult',
    'AwaitableGetProjectResult',
    'get_project',
    'get_project_output',
]

@pulumi.output_type
class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, built_in_environment_variables=None, description=None, environment_variable_aliases=None, environment_variables=None, id=None, name=None, organization_id=None, secret_aliases=None, secrets=None):
        if built_in_environment_variables and not isinstance(built_in_environment_variables, list):
            raise TypeError("Expected argument 'built_in_environment_variables' to be a list")
        pulumi.set(__self__, "built_in_environment_variables", built_in_environment_variables)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if environment_variable_aliases and not isinstance(environment_variable_aliases, list):
            raise TypeError("Expected argument 'environment_variable_aliases' to be a list")
        pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variables and not isinstance(environment_variables, list):
            raise TypeError("Expected argument 'environment_variables' to be a list")
        pulumi.set(__self__, "environment_variables", environment_variables)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if secret_aliases and not isinstance(secret_aliases, list):
            raise TypeError("Expected argument 'secret_aliases' to be a list")
        pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> Sequence['outputs.GetProjectBuiltInEnvironmentVariableResult']:
        """
        List of built-in environment variables linked to this project.
        """
        return pulumi.get(self, "built_in_environment_variables")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description of the project.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Sequence['outputs.GetProjectEnvironmentVariableAliasResult']:
        """
        List of environment variable aliases linked to this project.
        """
        return pulumi.get(self, "environment_variable_aliases")

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Sequence['outputs.GetProjectEnvironmentVariableResult']:
        """
        List of environment variables linked to this project.
        """
        return pulumi.get(self, "environment_variables")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Id of the project.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the project.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Sequence['outputs.GetProjectSecretAliasResult']:
        """
        List of secret aliases linked to this project.
        """
        return pulumi.get(self, "secret_aliases")

    @property
    @pulumi.getter
    def secrets(self) -> Sequence['outputs.GetProjectSecretResult']:
        """
        List of secrets linked to this project.
        """
        return pulumi.get(self, "secrets")


class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            built_in_environment_variables=self.built_in_environment_variables,
            description=self.description,
            environment_variable_aliases=self.environment_variable_aliases,
            environment_variables=self.environment_variables,
            id=self.id,
            name=self.name,
            organization_id=self.organization_id,
            secret_aliases=self.secret_aliases,
            secrets=self.secrets)


def get_project(description: Optional[str] = None,
                environment_variable_aliases: Optional[Sequence[pulumi.InputType['GetProjectEnvironmentVariableAliasArgs']]] = None,
                environment_variables: Optional[Sequence[pulumi.InputType['GetProjectEnvironmentVariableArgs']]] = None,
                id: Optional[str] = None,
                secret_aliases: Optional[Sequence[pulumi.InputType['GetProjectSecretAliasArgs']]] = None,
                secrets: Optional[Sequence[pulumi.InputType['GetProjectSecretArgs']]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectResult:
    """
    ## # Project (Data Source)

    Provides a Qovery project resource. This can be used to create and manage Qovery projects.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_project = qovery.get_project(id="<project_id>")
    ```


    :param str description: Description of the project.
    :param Sequence[pulumi.InputType['GetProjectEnvironmentVariableAliasArgs']] environment_variable_aliases: List of environment variable aliases linked to this project.
    :param Sequence[pulumi.InputType['GetProjectEnvironmentVariableArgs']] environment_variables: List of environment variables linked to this project.
    :param str id: Id of the environment variable.
    :param Sequence[pulumi.InputType['GetProjectSecretAliasArgs']] secret_aliases: List of secret aliases linked to this project.
    :param Sequence[pulumi.InputType['GetProjectSecretArgs']] secrets: List of secrets linked to this project.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['environmentVariableAliases'] = environment_variable_aliases
    __args__['environmentVariables'] = environment_variables
    __args__['id'] = id
    __args__['secretAliases'] = secret_aliases
    __args__['secrets'] = secrets
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getProject:getProject', __args__, opts=opts, typ=GetProjectResult).value

    return AwaitableGetProjectResult(
        built_in_environment_variables=pulumi.get(__ret__, 'built_in_environment_variables'),
        description=pulumi.get(__ret__, 'description'),
        environment_variable_aliases=pulumi.get(__ret__, 'environment_variable_aliases'),
        environment_variables=pulumi.get(__ret__, 'environment_variables'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        secret_aliases=pulumi.get(__ret__, 'secret_aliases'),
        secrets=pulumi.get(__ret__, 'secrets'))


@_utilities.lift_output_func(get_project)
def get_project_output(description: Optional[pulumi.Input[Optional[str]]] = None,
                       environment_variable_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProjectEnvironmentVariableAliasArgs']]]]] = None,
                       environment_variables: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProjectEnvironmentVariableArgs']]]]] = None,
                       id: Optional[pulumi.Input[str]] = None,
                       secret_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProjectSecretAliasArgs']]]]] = None,
                       secrets: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProjectSecretArgs']]]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetProjectResult]:
    """
    ## # Project (Data Source)

    Provides a Qovery project resource. This can be used to create and manage Qovery projects.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_project = qovery.get_project(id="<project_id>")
    ```


    :param str description: Description of the project.
    :param Sequence[pulumi.InputType['GetProjectEnvironmentVariableAliasArgs']] environment_variable_aliases: List of environment variable aliases linked to this project.
    :param Sequence[pulumi.InputType['GetProjectEnvironmentVariableArgs']] environment_variables: List of environment variables linked to this project.
    :param str id: Id of the environment variable.
    :param Sequence[pulumi.InputType['GetProjectSecretAliasArgs']] secret_aliases: List of secret aliases linked to this project.
    :param Sequence[pulumi.InputType['GetProjectSecretArgs']] secrets: List of secrets linked to this project.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetContainerResult',
    'AwaitableGetContainerResult',
    'get_container',
    'get_container_output',
]

@pulumi.output_type
class GetContainerResult:
    """
    A collection of values returned by getContainer.
    """
    def __init__(__self__, advanced_settings_json=None, arguments=None, auto_deploy=None, auto_preview=None, built_in_environment_variables=None, cpu=None, custom_domains=None, deployment_stage_id=None, entrypoint=None, environment_id=None, environment_variable_aliases=None, environment_variable_overrides=None, environment_variables=None, external_host=None, healthchecks=None, id=None, image_name=None, internal_host=None, max_running_instances=None, memory=None, min_running_instances=None, name=None, ports=None, registry_id=None, secret_aliases=None, secret_overrides=None, secrets=None, storages=None, tag=None):
        if advanced_settings_json and not isinstance(advanced_settings_json, str):
            raise TypeError("Expected argument 'advanced_settings_json' to be a str")
        pulumi.set(__self__, "advanced_settings_json", advanced_settings_json)
        if arguments and not isinstance(arguments, list):
            raise TypeError("Expected argument 'arguments' to be a list")
        pulumi.set(__self__, "arguments", arguments)
        if auto_deploy and not isinstance(auto_deploy, bool):
            raise TypeError("Expected argument 'auto_deploy' to be a bool")
        pulumi.set(__self__, "auto_deploy", auto_deploy)
        if auto_preview and not isinstance(auto_preview, bool):
            raise TypeError("Expected argument 'auto_preview' to be a bool")
        pulumi.set(__self__, "auto_preview", auto_preview)
        if built_in_environment_variables and not isinstance(built_in_environment_variables, list):
            raise TypeError("Expected argument 'built_in_environment_variables' to be a list")
        pulumi.set(__self__, "built_in_environment_variables", built_in_environment_variables)
        if cpu and not isinstance(cpu, int):
            raise TypeError("Expected argument 'cpu' to be a int")
        pulumi.set(__self__, "cpu", cpu)
        if custom_domains and not isinstance(custom_domains, list):
            raise TypeError("Expected argument 'custom_domains' to be a list")
        pulumi.set(__self__, "custom_domains", custom_domains)
        if deployment_stage_id and not isinstance(deployment_stage_id, str):
            raise TypeError("Expected argument 'deployment_stage_id' to be a str")
        pulumi.set(__self__, "deployment_stage_id", deployment_stage_id)
        if entrypoint and not isinstance(entrypoint, str):
            raise TypeError("Expected argument 'entrypoint' to be a str")
        pulumi.set(__self__, "entrypoint", entrypoint)
        if environment_id and not isinstance(environment_id, str):
            raise TypeError("Expected argument 'environment_id' to be a str")
        pulumi.set(__self__, "environment_id", environment_id)
        if environment_variable_aliases and not isinstance(environment_variable_aliases, list):
            raise TypeError("Expected argument 'environment_variable_aliases' to be a list")
        pulumi.set(__self__, "environment_variable_aliases", environment_variable_aliases)
        if environment_variable_overrides and not isinstance(environment_variable_overrides, list):
            raise TypeError("Expected argument 'environment_variable_overrides' to be a list")
        pulumi.set(__self__, "environment_variable_overrides", environment_variable_overrides)
        if environment_variables and not isinstance(environment_variables, list):
            raise TypeError("Expected argument 'environment_variables' to be a list")
        pulumi.set(__self__, "environment_variables", environment_variables)
        if external_host and not isinstance(external_host, str):
            raise TypeError("Expected argument 'external_host' to be a str")
        pulumi.set(__self__, "external_host", external_host)
        if healthchecks and not isinstance(healthchecks, dict):
            raise TypeError("Expected argument 'healthchecks' to be a dict")
        pulumi.set(__self__, "healthchecks", healthchecks)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_name and not isinstance(image_name, str):
            raise TypeError("Expected argument 'image_name' to be a str")
        pulumi.set(__self__, "image_name", image_name)
        if internal_host and not isinstance(internal_host, str):
            raise TypeError("Expected argument 'internal_host' to be a str")
        pulumi.set(__self__, "internal_host", internal_host)
        if max_running_instances and not isinstance(max_running_instances, int):
            raise TypeError("Expected argument 'max_running_instances' to be a int")
        pulumi.set(__self__, "max_running_instances", max_running_instances)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if min_running_instances and not isinstance(min_running_instances, int):
            raise TypeError("Expected argument 'min_running_instances' to be a int")
        pulumi.set(__self__, "min_running_instances", min_running_instances)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if ports and not isinstance(ports, list):
            raise TypeError("Expected argument 'ports' to be a list")
        pulumi.set(__self__, "ports", ports)
        if registry_id and not isinstance(registry_id, str):
            raise TypeError("Expected argument 'registry_id' to be a str")
        pulumi.set(__self__, "registry_id", registry_id)
        if secret_aliases and not isinstance(secret_aliases, list):
            raise TypeError("Expected argument 'secret_aliases' to be a list")
        pulumi.set(__self__, "secret_aliases", secret_aliases)
        if secret_overrides and not isinstance(secret_overrides, list):
            raise TypeError("Expected argument 'secret_overrides' to be a list")
        pulumi.set(__self__, "secret_overrides", secret_overrides)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)
        if storages and not isinstance(storages, list):
            raise TypeError("Expected argument 'storages' to be a list")
        pulumi.set(__self__, "storages", storages)
        if tag and not isinstance(tag, str):
            raise TypeError("Expected argument 'tag' to be a str")
        pulumi.set(__self__, "tag", tag)

    @property
    @pulumi.getter(name="advancedSettingsJson")
    def advanced_settings_json(self) -> str:
        return pulumi.get(self, "advanced_settings_json")

    @property
    @pulumi.getter
    def arguments(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "arguments")

    @property
    @pulumi.getter(name="autoDeploy")
    def auto_deploy(self) -> bool:
        return pulumi.get(self, "auto_deploy")

    @property
    @pulumi.getter(name="autoPreview")
    def auto_preview(self) -> bool:
        return pulumi.get(self, "auto_preview")

    @property
    @pulumi.getter(name="builtInEnvironmentVariables")
    def built_in_environment_variables(self) -> Sequence['outputs.GetContainerBuiltInEnvironmentVariableResult']:
        return pulumi.get(self, "built_in_environment_variables")

    @property
    @pulumi.getter
    def cpu(self) -> int:
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> Optional[Sequence['outputs.GetContainerCustomDomainResult']]:
        return pulumi.get(self, "custom_domains")

    @property
    @pulumi.getter(name="deploymentStageId")
    def deployment_stage_id(self) -> str:
        return pulumi.get(self, "deployment_stage_id")

    @property
    @pulumi.getter
    def entrypoint(self) -> str:
        return pulumi.get(self, "entrypoint")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> str:
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="environmentVariableAliases")
    def environment_variable_aliases(self) -> Optional[Sequence['outputs.GetContainerEnvironmentVariableAliasResult']]:
        return pulumi.get(self, "environment_variable_aliases")

    @property
    @pulumi.getter(name="environmentVariableOverrides")
    def environment_variable_overrides(self) -> Optional[Sequence['outputs.GetContainerEnvironmentVariableOverrideResult']]:
        return pulumi.get(self, "environment_variable_overrides")

    @property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[Sequence['outputs.GetContainerEnvironmentVariableResult']]:
        return pulumi.get(self, "environment_variables")

    @property
    @pulumi.getter(name="externalHost")
    def external_host(self) -> str:
        return pulumi.get(self, "external_host")

    @property
    @pulumi.getter
    def healthchecks(self) -> Optional['outputs.GetContainerHealthchecksResult']:
        return pulumi.get(self, "healthchecks")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> str:
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="internalHost")
    def internal_host(self) -> str:
        return pulumi.get(self, "internal_host")

    @property
    @pulumi.getter(name="maxRunningInstances")
    def max_running_instances(self) -> int:
        return pulumi.get(self, "max_running_instances")

    @property
    @pulumi.getter
    def memory(self) -> int:
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter(name="minRunningInstances")
    def min_running_instances(self) -> int:
        return pulumi.get(self, "min_running_instances")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def ports(self) -> Sequence['outputs.GetContainerPortResult']:
        return pulumi.get(self, "ports")

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> str:
        return pulumi.get(self, "registry_id")

    @property
    @pulumi.getter(name="secretAliases")
    def secret_aliases(self) -> Optional[Sequence['outputs.GetContainerSecretAliasResult']]:
        return pulumi.get(self, "secret_aliases")

    @property
    @pulumi.getter(name="secretOverrides")
    def secret_overrides(self) -> Optional[Sequence['outputs.GetContainerSecretOverrideResult']]:
        return pulumi.get(self, "secret_overrides")

    @property
    @pulumi.getter
    def secrets(self) -> Optional[Sequence['outputs.GetContainerSecretResult']]:
        return pulumi.get(self, "secrets")

    @property
    @pulumi.getter
    def storages(self) -> Sequence['outputs.GetContainerStorageResult']:
        return pulumi.get(self, "storages")

    @property
    @pulumi.getter
    def tag(self) -> str:
        return pulumi.get(self, "tag")


class AwaitableGetContainerResult(GetContainerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetContainerResult(
            advanced_settings_json=self.advanced_settings_json,
            arguments=self.arguments,
            auto_deploy=self.auto_deploy,
            auto_preview=self.auto_preview,
            built_in_environment_variables=self.built_in_environment_variables,
            cpu=self.cpu,
            custom_domains=self.custom_domains,
            deployment_stage_id=self.deployment_stage_id,
            entrypoint=self.entrypoint,
            environment_id=self.environment_id,
            environment_variable_aliases=self.environment_variable_aliases,
            environment_variable_overrides=self.environment_variable_overrides,
            environment_variables=self.environment_variables,
            external_host=self.external_host,
            healthchecks=self.healthchecks,
            id=self.id,
            image_name=self.image_name,
            internal_host=self.internal_host,
            max_running_instances=self.max_running_instances,
            memory=self.memory,
            min_running_instances=self.min_running_instances,
            name=self.name,
            ports=self.ports,
            registry_id=self.registry_id,
            secret_aliases=self.secret_aliases,
            secret_overrides=self.secret_overrides,
            secrets=self.secrets,
            storages=self.storages,
            tag=self.tag)


def get_container(advanced_settings_json: Optional[str] = None,
                  arguments: Optional[Sequence[str]] = None,
                  auto_deploy: Optional[bool] = None,
                  auto_preview: Optional[bool] = None,
                  cpu: Optional[int] = None,
                  custom_domains: Optional[Sequence[pulumi.InputType['GetContainerCustomDomainArgs']]] = None,
                  deployment_stage_id: Optional[str] = None,
                  entrypoint: Optional[str] = None,
                  environment_variable_aliases: Optional[Sequence[pulumi.InputType['GetContainerEnvironmentVariableAliasArgs']]] = None,
                  environment_variable_overrides: Optional[Sequence[pulumi.InputType['GetContainerEnvironmentVariableOverrideArgs']]] = None,
                  environment_variables: Optional[Sequence[pulumi.InputType['GetContainerEnvironmentVariableArgs']]] = None,
                  healthchecks: Optional[pulumi.InputType['GetContainerHealthchecksArgs']] = None,
                  id: Optional[str] = None,
                  max_running_instances: Optional[int] = None,
                  memory: Optional[int] = None,
                  min_running_instances: Optional[int] = None,
                  ports: Optional[Sequence[pulumi.InputType['GetContainerPortArgs']]] = None,
                  secret_aliases: Optional[Sequence[pulumi.InputType['GetContainerSecretAliasArgs']]] = None,
                  secret_overrides: Optional[Sequence[pulumi.InputType['GetContainerSecretOverrideArgs']]] = None,
                  secrets: Optional[Sequence[pulumi.InputType['GetContainerSecretArgs']]] = None,
                  storages: Optional[Sequence[pulumi.InputType['GetContainerStorageArgs']]] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetContainerResult:
    """
    ## # Container (Data Source)

    Provides a Qovery container resource. This can be used to create and manage Qovery container registry.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_container = qovery.get_container(id="<container_id>")
    ```
    """
    __args__ = dict()
    __args__['advancedSettingsJson'] = advanced_settings_json
    __args__['arguments'] = arguments
    __args__['autoDeploy'] = auto_deploy
    __args__['autoPreview'] = auto_preview
    __args__['cpu'] = cpu
    __args__['customDomains'] = custom_domains
    __args__['deploymentStageId'] = deployment_stage_id
    __args__['entrypoint'] = entrypoint
    __args__['environmentVariableAliases'] = environment_variable_aliases
    __args__['environmentVariableOverrides'] = environment_variable_overrides
    __args__['environmentVariables'] = environment_variables
    __args__['healthchecks'] = healthchecks
    __args__['id'] = id
    __args__['maxRunningInstances'] = max_running_instances
    __args__['memory'] = memory
    __args__['minRunningInstances'] = min_running_instances
    __args__['ports'] = ports
    __args__['secretAliases'] = secret_aliases
    __args__['secretOverrides'] = secret_overrides
    __args__['secrets'] = secrets
    __args__['storages'] = storages
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getContainer:getContainer', __args__, opts=opts, typ=GetContainerResult).value

    return AwaitableGetContainerResult(
        advanced_settings_json=pulumi.get(__ret__, 'advanced_settings_json'),
        arguments=pulumi.get(__ret__, 'arguments'),
        auto_deploy=pulumi.get(__ret__, 'auto_deploy'),
        auto_preview=pulumi.get(__ret__, 'auto_preview'),
        built_in_environment_variables=pulumi.get(__ret__, 'built_in_environment_variables'),
        cpu=pulumi.get(__ret__, 'cpu'),
        custom_domains=pulumi.get(__ret__, 'custom_domains'),
        deployment_stage_id=pulumi.get(__ret__, 'deployment_stage_id'),
        entrypoint=pulumi.get(__ret__, 'entrypoint'),
        environment_id=pulumi.get(__ret__, 'environment_id'),
        environment_variable_aliases=pulumi.get(__ret__, 'environment_variable_aliases'),
        environment_variable_overrides=pulumi.get(__ret__, 'environment_variable_overrides'),
        environment_variables=pulumi.get(__ret__, 'environment_variables'),
        external_host=pulumi.get(__ret__, 'external_host'),
        healthchecks=pulumi.get(__ret__, 'healthchecks'),
        id=pulumi.get(__ret__, 'id'),
        image_name=pulumi.get(__ret__, 'image_name'),
        internal_host=pulumi.get(__ret__, 'internal_host'),
        max_running_instances=pulumi.get(__ret__, 'max_running_instances'),
        memory=pulumi.get(__ret__, 'memory'),
        min_running_instances=pulumi.get(__ret__, 'min_running_instances'),
        name=pulumi.get(__ret__, 'name'),
        ports=pulumi.get(__ret__, 'ports'),
        registry_id=pulumi.get(__ret__, 'registry_id'),
        secret_aliases=pulumi.get(__ret__, 'secret_aliases'),
        secret_overrides=pulumi.get(__ret__, 'secret_overrides'),
        secrets=pulumi.get(__ret__, 'secrets'),
        storages=pulumi.get(__ret__, 'storages'),
        tag=pulumi.get(__ret__, 'tag'))


@_utilities.lift_output_func(get_container)
def get_container_output(advanced_settings_json: Optional[pulumi.Input[Optional[str]]] = None,
                         arguments: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                         auto_deploy: Optional[pulumi.Input[Optional[bool]]] = None,
                         auto_preview: Optional[pulumi.Input[Optional[bool]]] = None,
                         cpu: Optional[pulumi.Input[Optional[int]]] = None,
                         custom_domains: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerCustomDomainArgs']]]]] = None,
                         deployment_stage_id: Optional[pulumi.Input[Optional[str]]] = None,
                         entrypoint: Optional[pulumi.Input[Optional[str]]] = None,
                         environment_variable_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerEnvironmentVariableAliasArgs']]]]] = None,
                         environment_variable_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerEnvironmentVariableOverrideArgs']]]]] = None,
                         environment_variables: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerEnvironmentVariableArgs']]]]] = None,
                         healthchecks: Optional[pulumi.Input[Optional[pulumi.InputType['GetContainerHealthchecksArgs']]]] = None,
                         id: Optional[pulumi.Input[str]] = None,
                         max_running_instances: Optional[pulumi.Input[Optional[int]]] = None,
                         memory: Optional[pulumi.Input[Optional[int]]] = None,
                         min_running_instances: Optional[pulumi.Input[Optional[int]]] = None,
                         ports: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerPortArgs']]]]] = None,
                         secret_aliases: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerSecretAliasArgs']]]]] = None,
                         secret_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerSecretOverrideArgs']]]]] = None,
                         secrets: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerSecretArgs']]]]] = None,
                         storages: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetContainerStorageArgs']]]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetContainerResult]:
    """
    ## # Container (Data Source)

    Provides a Qovery container resource. This can be used to create and manage Qovery container registry.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_container = qovery.get_container(id="<container_id>")
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetContainerRegistryResult',
    'AwaitableGetContainerRegistryResult',
    'get_container_registry',
    'get_container_registry_output',
]

@pulumi.output_type
class GetContainerRegistryResult:
    """
    A collection of values returned by getContainerRegistry.
    """
    def __init__(__self__, description=None, id=None, kind=None, name=None, organization_id=None, url=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def kind(self) -> str:
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def url(self) -> str:
        return pulumi.get(self, "url")


class AwaitableGetContainerRegistryResult(GetContainerRegistryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetContainerRegistryResult(
            description=self.description,
            id=self.id,
            kind=self.kind,
            name=self.name,
            organization_id=self.organization_id,
            url=self.url)


def get_container_registry(description: Optional[str] = None,
                           id: Optional[str] = None,
                           organization_id: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetContainerRegistryResult:
    """
    ## # ContainerRegistry (Data Source)

    Provides a Qovery container registry resource. This can be used to create and manage Qovery container registry.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_container_registry = qovery.get_container_registry(id="<container_registry_id>")
    ```
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['id'] = id
    __args__['organizationId'] = organization_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getContainerRegistry:getContainerRegistry', __args__, opts=opts, typ=GetContainerRegistryResult).value

    return AwaitableGetContainerRegistryResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        kind=pulumi.get(__ret__, 'kind'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        url=pulumi.get(__ret__, 'url'))


@_utilities.lift_output_func(get_container_registry)
def get_container_registry_output(description: Optional[pulumi.Input[Optional[str]]] = None,
                                  id: Optional[pulumi.Input[str]] = None,
                                  organization_id: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetContainerRegistryResult]:
    """
    ## # ContainerRegistry (Data Source)

    Provides a Qovery container registry resource. This can be used to create and manage Qovery container registry.
    ## Example Usage

    ```python
    import pulumi
    import pulumi_qovery as qovery

    my_container_registry = qovery.get_container_registry(id="<container_registry_id>")
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .application import *
from .aws_credentials import *
from .cluster import *
from .container import *
from .container_registry import *
from .database import *
from .deployment import *
from .deployment_stage import *
from .environment import *
from .get_application import *
from .get_aws_credentials import *
from .get_cluster import *
from .get_container import *
from .get_container_registry import *
from .get_database import *
from .get_deployment import *
from .get_deployment_stage import *
from .get_environment import *
from .get_git_token import *
from .get_helm import *
from .get_helm_repository import *
from .get_job import *
from .get_organization import *
from .get_project import *
from .get_scaleway_credentials import *
from .git_token import *
from .helm import *
from .helm_repository import *
from .job import *
from .organization import *
from .project import *
from .provider import *
from .scaleway_credentials import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import ediri_qovery.config as __config
    config = __config
else:
    config = _utilities.lazy_import('ediri_qovery.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "qovery",
  "mod": "index/application",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/application:Application": "Application"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/awsCredentials",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/awsCredentials:AwsCredentials": "AwsCredentials"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/cluster",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/container",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/container:Container": "Container"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/containerRegistry",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/containerRegistry:ContainerRegistry": "ContainerRegistry"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/database",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/database:Database": "Database"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/deployment",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/deploymentStage",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/deploymentStage:DeploymentStage": "DeploymentStage"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/environment",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/gitToken",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/gitToken:GitToken": "GitToken"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/helm",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/helm:Helm": "Helm"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/helmRepository",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/helmRepository:HelmRepository": "HelmRepository"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/job",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/job:Job": "Job"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/organization",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/project",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/project:Project": "Project"
  }
 },
 {
  "pkg": "qovery",
  "mod": "index/scalewayCredentials",
  "fqn": "ediri_qovery",
  "classes": {
   "qovery:index/scalewayCredentials:ScalewayCredentials": "ScalewayCredentials"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "qovery",
  "token": "pulumi:providers:qovery",
  "fqn": "ediri_qovery",
  "class": "Provider"
 }
]
"""
)
